@@ -20,7 +20,10 @@ class Converter:
             error_msg (String) : Custom error message
         """
         try:
-            return None if not value else int(value)
+            if value is None:
+                return None
+
+            return int(value)
         except ValueError:
             if error_msg is None:
                 error_msg = FlaUiError.ValueShouldBeANumber.format(value)
@@ -31,18 +34,26 @@ class Converter:
     def cast_to_string(value: Any):
         """
         Helper to cast value as string.
+        If value is None empty string will be returned.
 
         Args:
             value (Object): Value to convert
         """
-        return "" if not value else str(value)
+        if value is None:
+            return ""
+
+        return str(value)
 
     @staticmethod
     def cast_to_bool(value: Any):
         """
         Helper to cast value as bool.
+        If value is None False will be returned.
 
         Args:
             value (Object): Value to convert
         """
-        return "" if not value else bool(value)
+        if value is None:
+            return False
+
+        return bool(value)
